using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Data;

namespace WindowsApplication1
{
	/// <summary>
	/// Summary description for Form1.
	/// </summary>
	public class Form1 : System.Windows.Forms.Form
	{
		private System.ComponentModel.IContainer components;

		private System.Windows.Forms.Button button1;
		private System.Windows.Forms.Button button2;
        private System.Windows.Forms.Timer timer1;
        private XYChartNet.XYChartNETCtl xyChartNETCtl1;
		private Random rnd = new Random();

		public Form1()
		{
			InitializeComponent();

			// Add the following code after the call to InitializeComponent
			const int myNumSamples = 3600;

			Font myFont = new Font("Arial", 16, FontStyle.Bold | FontStyle.Italic);

			button1.Text = "Start";
			button2.Text = "Stop";

			button1.BringToFront();
			button2.BringToFront();

            xyChartNETCtl1.Dock = DockStyle.Fill;

			// Configure XY Chart NET control
			xyChartNETCtl1.NumProfiles = 3;
			xyChartNETCtl1.NumXScales = 1;
			xyChartNETCtl1.NumYScales = 1;

			xyChartNETCtl1.Title.Label = "Date Time Trending";
			xyChartNETCtl1.Title.Font = myFont;
			xyChartNETCtl1.Title.Color = Color.White;

			xyChartNETCtl1.Trend.Enable = true;
			xyChartNETCtl1.Trend.DisplayLength =  1 / 24.0 / 60.0 / 4.0; // Display 15 second range while trending

			// Legend
			xyChartNETCtl1.Legend.Visible = true;
			xyChartNETCtl1.Legend.BorderVisible = false;
			xyChartNETCtl1.Legend.YScaleVisible = false;

			// Gradient
			xyChartNETCtl1.Gradient.GradientOption = XYChartNet.XYChartNETCtl.GradientOptions.goCustom;
			xyChartNETCtl1.Gradient.StartColor = Color.LightSteelBlue;
			xyChartNETCtl1.Gradient.EndColor = Color.RoyalBlue;
			xyChartNETCtl1.Gradient.Orientation = XYChartNet.XYChartNETCtl.OrientationOptions.ooVertical;

			// Plot formatting
			xyChartNETCtl1.Plot.Transparent = true;
			xyChartNETCtl1.Plot.Border.LineOption = XYChartNet.XYChartNETCtl.LineOptions.loNone;

			// Toolbar
			xyChartNETCtl1.Toolbar.Visible = true;
			xyChartNETCtl1.Toolbar.BackColor = Color.LightSteelBlue;
			xyChartNETCtl1.Toolbar.Dock = XYChartNet.XYChartNETCtl.PositionOptions.poTop;

			// Crosshairs
			xyChartNETCtl1.Crosshairs.YCoordInLegend = true;
            xyChartNETCtl1.Crosshairs.Color = Color.DarkOrange;
			xyChartNETCtl1.Crosshairs.Width = XYChartNet.XYChartNETCtl.WidthOptions.woThreePoint;
            xyChartNETCtl1.Crosshairs.CoordsBackcolor = Color.DarkSalmon;
			xyChartNETCtl1.Crosshairs.HorizontalVisible = false;
			xyChartNETCtl1.Crosshairs.VerticalVisible = true;

			// Zoom Window
			xyChartNETCtl1.ZoomWindowColor= Color.DarkSlateGray ;

			// X Axis Grid & Scale properties
			XYChartNet.XYChartNETCtl.C_XSCALEPROP xAxis;
			xAxis = xyChartNETCtl1.get_XAxis(0);
			xAxis.Grid.LineOption = XYChartNet.XYChartNETCtl.LineOptions.loCustom;
			xAxis.Grid.LineStyle = XYChartNet.XYChartNETCtl.StyleOptions.soSolid;
			xAxis.Grid.LineColor = Color.Green;
			xAxis.Scale.Label = "";
			xAxis.Scale.TicksColor = Color.White;
			xAxis.Scale.ScaleMode = XYChartNet.XYChartNETCtl.ScaleModes.smAuto;
			xAxis.Scale.FormatStyle = XYChartNet.XYChartNETCtl.FormatStyles.fsDateTime;
			xAxis.Scale.DateTimeFormat = "hh:mm:ss tt"; 
			// xAxis.Scale.DateTimeFormat = "hh:mm:ss.fff tt"; // For more precision down to ms, use "hh:mm:ss.fff tt"
			// xAxis.Scale.DateTimeFormat = "MMM dd, yyyy  hh:mm:ss tt"; // Date also included

			// Y Axis Grid & Scale properties
			XYChartNet.XYChartNETCtl.C_YSCALEPROP yAxis;
			yAxis = xyChartNETCtl1.get_YAxis(0);
			yAxis.Grid.LineOption = XYChartNet.XYChartNETCtl.LineOptions.loCustom;
			yAxis.Grid.LineStyle = XYChartNet.XYChartNETCtl.StyleOptions.soSolid;
			yAxis.Grid.LineColor = Color.Green;
			yAxis.Scale.Label = "";
			yAxis.Scale.LabelColor = Color.White;
			yAxis.Scale.TicksColor = Color.White;
			yAxis.Scale.ScaleMode = XYChartNet.XYChartNETCtl.ScaleModes.smManual;
			yAxis.Scale.ScaleManualMin = 0;
			yAxis.Scale.ScaleManualMax = 100;

			XYChartNet.XYChartNETCtl.C_Profile profile;

			// Profile 0
			profile = xyChartNETCtl1.get_Profile(0);
			profile.YScale = 0;
			profile.Label = "Random 0";
			profile.LineOption = XYChartNet.XYChartNETCtl.LineOptions.loCustom;
			profile.LineWidth = XYChartNet.XYChartNETCtl.WidthOptions.woOnePoint;
			profile.LineStyle = XYChartNet.XYChartNETCtl.StyleOptions.soSolid;
			profile.LineColor = Color.Red;
			profile.MarkerOption = XYChartNet.XYChartNETCtl.LineOptions.loNone;
			profile.NumSamples = myNumSamples;

			// Profile 1
			profile = xyChartNETCtl1.get_Profile(1);
			profile.YScale = 0;
			profile.Label = "Random 1";
			profile.LineOption = XYChartNet.XYChartNETCtl.LineOptions.loCustom;
			profile.LineWidth = XYChartNet.XYChartNETCtl.WidthOptions.woOnePoint;
			profile.LineStyle = XYChartNet.XYChartNETCtl.StyleOptions.soSolid;
			profile.LineColor = Color.Blue;
			profile.MarkerOption = XYChartNet.XYChartNETCtl.LineOptions.loNone;
			profile.NumSamples = myNumSamples;

			// Profile 2
			profile = xyChartNETCtl1.get_Profile(2);
			profile.YScale = 0;
			profile.Label = "Random 2";
			profile.LineOption = XYChartNet.XYChartNETCtl.LineOptions.loCustom;
			profile.LineWidth = XYChartNet.XYChartNETCtl.WidthOptions.woOnePoint;
			profile.LineStyle = XYChartNet.XYChartNETCtl.StyleOptions.soSolid;
			profile.LineColor = Color.Yellow;
			profile.MarkerOption = XYChartNet.XYChartNETCtl.LineOptions.loNone;
			profile.NumSamples = myNumSamples;

			xyChartNETCtl1.ClearChartData();

			xyChartNETCtl1.Refresh();

			// Start timer
			timer1.Interval = 100;
			timer1.Enabled = true;

		}

		// Timer Event
		private void timer1_Tick(object sender, System.EventArgs e)
		{
			double[,] NewData = new double[1, 6];
			DateTime dtNow  = DateTime.Now;

			NewData[0, 0] = dtNow.ToOADate();
			NewData[0, 1] = 30 * rnd.NextDouble() + 70;
			NewData[0, 2] = dtNow.ToOADate();
			NewData[0, 3] = 30 * rnd.NextDouble() + 40;
			NewData[0, 4] = dtNow.ToOADate();
			NewData[0, 5] = 30 * rnd.NextDouble() + 10;

			// Add new trend data to chart array
			xyChartNETCtl1.Trend.AddData(1, NewData, XYChartNet.XYChartNETCtl.AppendOpts.aoAppendToEnd);
            xyChartNETCtl1.Refresh();
		}


		// Start Trending
		private void button1_Click(object sender, System.EventArgs e)
		{
			timer1.Enabled = true;

			xyChartNETCtl1.Trend.Enable = true;
			xyChartNETCtl1.Refresh();
		}

		// Stop Trending
		private void button2_Click(object sender, System.EventArgs e)
		{
			timer1.Enabled = false;

			xyChartNETCtl1.Trend.Enable = false;
			xyChartNETCtl1.Refresh();
		}


		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if (components != null) 
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
            this.components = new System.ComponentModel.Container();
            System.ComponentModel.ComponentResourceManager resources = new System.ComponentModel.ComponentResourceManager(typeof(Form1));
            this.button1 = new System.Windows.Forms.Button();
            this.button2 = new System.Windows.Forms.Button();
            this.timer1 = new System.Windows.Forms.Timer(this.components);
            this.xyChartNETCtl1 = new XYChartNet.XYChartNETCtl();
            this.SuspendLayout();
            // 
            // button1
            // 
            this.button1.Location = new System.Drawing.Point(248, 2);
            this.button1.Name = "button1";
            this.button1.Size = new System.Drawing.Size(50, 22);
            this.button1.TabIndex = 1;
            this.button1.Text = "button1";
            this.button1.Click += new System.EventHandler(this.button1_Click);
            // 
            // button2
            // 
            this.button2.Location = new System.Drawing.Point(304, 2);
            this.button2.Name = "button2";
            this.button2.Size = new System.Drawing.Size(50, 22);
            this.button2.TabIndex = 2;
            this.button2.Text = "button2";
            this.button2.Click += new System.EventHandler(this.button2_Click);
            // 
            // timer1
            // 
            this.timer1.Tick += new System.EventHandler(this.timer1_Tick);
            // 
            // xyChartNETCtl1
            // 
            this.xyChartNETCtl1.BackColor = System.Drawing.SystemColors.Control;
            this.xyChartNETCtl1.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("xyChartNETCtl1.BackgroundImage")));
            this.xyChartNETCtl1.Border.LineOption = XYChartNet.XYChartNETCtl.LineOptions.loNone;
            this.xyChartNETCtl1.CausesValidation = false;
            this.xyChartNETCtl1.CustomToolbar.BackColor = System.Drawing.SystemColors.Control;
            this.xyChartNETCtl1.Location = new System.Drawing.Point(27, 74);
            this.xyChartNETCtl1.LogEvent.CTRLInstName = "XYChartNETCtl1";
            this.xyChartNETCtl1.LogEvent.FormName = "Form1";
            this.xyChartNETCtl1.Name = "xyChartNETCtl1";
            this.xyChartNETCtl1.Size = new System.Drawing.Size(462, 277);
            this.xyChartNETCtl1.TabIndex = 3;
            this.xyChartNETCtl1.Title.Font = new System.Drawing.Font("Arial", 8F);
            this.xyChartNETCtl1.Toolbar.BackColor = System.Drawing.Color.FromArgb(((int)(((byte)(211)))), ((int)(((byte)(222)))), ((int)(((byte)(237)))));
            // 
            // Form1
            // 
            this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
            this.ClientSize = new System.Drawing.Size(792, 486);
            this.Controls.Add(this.button2);
            this.Controls.Add(this.button1);
            this.Controls.Add(this.xyChartNETCtl1);
            this.Name = "Form1";
            this.StartPosition = System.Windows.Forms.FormStartPosition.CenterScreen;
            this.Text = "Form1";
            this.ResumeLayout(false);

		}
		#endregion

		/// <summary>
		/// The main entry point for the application.
		/// </summary>
		[STAThread]
		static void Main() 
		{
			Application.Run(new Form1());
		}
	}
}
