using System;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Windows.Forms;

namespace Sample1
{
	/// <summary>
	/// Summary description for Form1.
	/// </summary>
	public class Form1 : System.Windows.Forms.Form
    {
        private XYChartNet.XYChartNETCtl xyChartNETCtl1;
		/// <summary>
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;

		public Form1()
		{
			//
			// Required for Windows Form Designer support
			//
			InitializeComponent();

			const int    myNumSamples = 73;
			const int    myXYSet = 4;

			double     val;
			double [,] DataArray = new double [myNumSamples, myXYSet];
			int row; 

			Font myFont = new Font("Arial", 16, FontStyle.Italic | FontStyle.Bold);

            xyChartNETCtl1.Dock = DockStyle.Fill;

			// Configure XY Chart NET control 
			xyChartNETCtl1.NumProfiles = 2; 
			xyChartNETCtl1.NumXScales = 1; 
			xyChartNETCtl1.NumYScales = 1; 
        
			// Zoom window 
			xyChartNETCtl1.ZoomWindowColor = Color.Yellow; 
        
			// Backcolor 
			xyChartNETCtl1.BackColor = Color.Black; 
        
			//Plot formatting 
			xyChartNETCtl1.Plot.Transparent = true; 
			xyChartNETCtl1.Plot.Border.LineOption = XYChartNet.XYChartNETCtl.LineOptions.loNone; 
        
			// Toolbar 
			xyChartNETCtl1.Toolbar.Visible = true; 
			xyChartNETCtl1.Toolbar.BackColor = Color.LightSteelBlue; 
			xyChartNETCtl1.Toolbar.Dock = XYChartNet.XYChartNETCtl.PositionOptions.poTop; 
        
			// Format Legend 
			xyChartNETCtl1.Legend.Visible = true; 
			xyChartNETCtl1.Legend.BorderVisible = false; 
			xyChartNETCtl1.Legend.YScaleVisible = false; 
        
			// Format Crosshairs 
			xyChartNETCtl1.Crosshairs.YCoordInLegend = true; 
			xyChartNETCtl1.Crosshairs.Color = Color.Yellow; 
			xyChartNETCtl1.Crosshairs.Width = XYChartNet.XYChartNETCtl.WidthOptions.woTwoPoint; 
			xyChartNETCtl1.Crosshairs.CoordsBackcolor = Color.Brown; 
			xyChartNETCtl1.Crosshairs.HorizontalVisible = false; 
			xyChartNETCtl1.Crosshairs.VerticalVisible = true;

            // Format Delta Crosshairs 
            xyChartNETCtl1.DeltaCrosshairs.Delta1HorizCoordsBackcolor = Color.Blue;
            xyChartNETCtl1.DeltaCrosshairs.Delta2HorizCoordsBackcolor = Color.DarkGreen;
            xyChartNETCtl1.DeltaCrosshairs.Delta1VertCoordsBackcolor = Color.Blue;
            xyChartNETCtl1.DeltaCrosshairs.Delta2VertCoordsBackcolor = Color.DarkGreen; 

			// X Axis Grid & Scale properties
			XYChartNet.XYChartNETCtl.C_XSCALEPROP xAxis;
			xAxis = xyChartNETCtl1.get_XAxis(0);
			xAxis.Grid.LineOption = XYChartNet.XYChartNETCtl.LineOptions.loNone; 
			xAxis.Scale.Label = "Time (ms)"; 
			xAxis.Scale.LabelColor = Color.White; 
			xAxis.Scale.TicksColor = Color.White; 
        
        
			// Y Axis Grid & Scale properties
			XYChartNet.XYChartNETCtl.C_YSCALEPROP yAxis;
			yAxis = xyChartNETCtl1.get_YAxis(0);
			yAxis.Grid.LineOption = XYChartNet.XYChartNETCtl.LineOptions.loNone; 
			yAxis.Scale.Visible = true; 
			yAxis.Scale.Label = "Volts"; 
			yAxis.Scale.LabelColor = Color.White; 
			yAxis.Scale.TicksColor = Color.White; 
        
			// Format Profile 0 
			XYChartNet.XYChartNETCtl.C_Profile profile0;
			profile0 = xyChartNETCtl1.get_Profile(0);
			profile0.Label = "SINE"; 
			profile0.YScale = 0; 
			profile0.NumSamples = myNumSamples; 
			profile0.LineOption = XYChartNet.XYChartNETCtl.LineOptions.loCustom; 
			profile0.LineWidth = XYChartNet.XYChartNETCtl.WidthOptions.woThreePoint; 
			profile0.LineStyle = XYChartNet.XYChartNETCtl.StyleOptions.soSolid; 
			profile0.MarkerOption = XYChartNet.XYChartNETCtl.LineOptions.loNone; 
			profile0.LineColor = Color.Blue; 
			profile0.FillEnabled = true; 
			profile0.FillColor = Color.FromArgb(128, 0, 0, 128); 
        
			// Format Profile 1 
			XYChartNet.XYChartNETCtl.C_Profile profile1;
			profile1 = xyChartNETCtl1.get_Profile(1);
			profile1.Label = "COSINE"; 
			profile1.YScale = 0; 
			profile1.NumSamples = myNumSamples; 
			profile1.LineOption = XYChartNet.XYChartNETCtl.LineOptions.loCustom; 
			profile1.LineWidth = XYChartNet.XYChartNETCtl.WidthOptions.woThreePoint; 
			profile1.LineStyle = XYChartNet.XYChartNETCtl.StyleOptions.soSolid; 
			profile1.MarkerOption = XYChartNet.XYChartNETCtl.LineOptions.loNone; 
			profile1.LineColor = Color.Red; 
			profile1.FillEnabled = true; 
			profile1.FillColor = Color.FromArgb(128, 255, 0, 0); 
        
			// Generate Sine and Cosine profiles 
			for (row = 0; row <= myNumSamples - 1; row++) 
			{ 
				// Profile 0
				val = 2 * modXYChart.PI * row / (myNumSamples-1);
				DataArray[row, 0] = val;
				DataArray[row, 1] = Math.Sin(val);

				// Profile 1
				DataArray[row, 2] = val;
				DataArray[row, 3] = Math.Cos(val);
			} 
        
			// Feed source array into XYChart 
			xyChartNETCtl1.ChartData = DataArray;  
        
			xyChartNETCtl1.Refresh();  
		}  
    

		private void XyChartNETCtl1_DrawGridLines(System.Drawing.Graphics gCanvas) 
		{ 
			modXYChart myModXYChart = new modXYChart();

			// Draw hatches after grid lines and before any profiles are drawn 
			// Top 
			myModXYChart.DrawShapeOnCanvas(gCanvas, xyChartNETCtl1, 0, 0, 0, 2 * modXYChart.PI, 0.5, 1, modXYChart.eShape.Rectangle, true, 
				xyChartNETCtl1.BackColor, false, Color.Green, 1, System.Drawing.Drawing2D.HatchStyle.DiagonalCross, Color.Green); 
			// Bottom 
			myModXYChart.DrawShapeOnCanvas(gCanvas, xyChartNETCtl1, 0, 0, 0, 2 * modXYChart.PI, -1, -0.5, modXYChart.eShape.Rectangle, true, 
				xyChartNETCtl1.BackColor, false, Color.Green, 1, System.Drawing.Drawing2D.HatchStyle.DiagonalCross, Color.Green); 
		} 


		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if (components != null) 
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
            System.ComponentModel.ComponentResourceManager resources = new System.ComponentModel.ComponentResourceManager(typeof(Form1));
            this.xyChartNETCtl1 = new XYChartNet.XYChartNETCtl();
            this.SuspendLayout();
            // 
            // xyChartNETCtl1
            // 
            this.xyChartNETCtl1.BackColor = System.Drawing.SystemColors.Control;
            this.xyChartNETCtl1.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("xyChartNETCtl1.BackgroundImage")));
            this.xyChartNETCtl1.Border.LineOption = XYChartNet.XYChartNETCtl.LineOptions.loNone;
            this.xyChartNETCtl1.CausesValidation = false;
            this.xyChartNETCtl1.CustomToolbar.BackColor = System.Drawing.SystemColors.Control;
            this.xyChartNETCtl1.Location = new System.Drawing.Point(42, 55);
            this.xyChartNETCtl1.LogEvent.CTRLInstName = "XYChartNETCtl1";
            this.xyChartNETCtl1.LogEvent.FormName = "Form1";
            this.xyChartNETCtl1.Name = "xyChartNETCtl1";
            this.xyChartNETCtl1.Size = new System.Drawing.Size(424, 313);
            this.xyChartNETCtl1.TabIndex = 0;
            this.xyChartNETCtl1.Title.Font = new System.Drawing.Font("Arial", 8F);
            this.xyChartNETCtl1.Toolbar.BackColor = System.Drawing.Color.FromArgb(((int)(((byte)(211)))), ((int)(((byte)(222)))), ((int)(((byte)(237)))));
            this.xyChartNETCtl1.DrawGridLines += new XYChartNet.XYChartNETCtl.DrawGridLinesEventHandler(this.XyChartNETCtl1_DrawGridLines);
            // 
            // Form1
            // 
            this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
            this.ClientSize = new System.Drawing.Size(810, 518);
            this.Controls.Add(this.xyChartNETCtl1);
            this.Name = "Form1";
            this.StartPosition = System.Windows.Forms.FormStartPosition.CenterScreen;
            this.Text = "Form1";
            this.ResumeLayout(false);

		}
		#endregion

		/// <summary>
		/// The main entry point for the application.
		/// </summary>
		[STAThread]
		static void Main() 
		{
			Application.Run(new Form1());
		}
	}
}
