Imports System.Drawing.Drawing2D

Module modXYChart

    Public Const PI As Double = 3.14159265358979
    Public Const NULL_DATA_VALUE As Double = 1.79 * 10 ^ 308

    Public Enum eShape As Integer
        Rectangle = 0
        Elipse = 1
    End Enum
    '

    Public Sub PositionCrosshairsAtNearestDataPoint(ByVal Index As Integer, _
                                                    ByVal xPos As Double, _
                                                    ByVal yPos As Double, _
                                                    ByRef XYChart As XYChartNet.XYChartNETCtl)

        ' Supports Linear and Log scales and with Y Stacking

        Dim iProfile As Integer
        Dim lRow As Long
        Dim dXValue As Double
        Dim dYValue As Double

        Dim iXScale As Integer
        Dim iYScale As Integer

        Try
            If GetNearestDataPoint(Index, xPos, yPos, iProfile, lRow, dXValue, dYValue, XYChart) Then
                With XYChart
                    ' Get XScale and YScale
                    iXScale = .Profile(iProfile).XScale
                    iYScale = .Profile(iProfile).YScale

                    If FormatNumber(dXValue, 16) = FormatNumber(CDbl(.XCoordinate(iXScale, False)), 16) And _
                       FormatNumber(dYValue, 16) = FormatNumber(CDbl(.YCoordinate(iYScale, False)), 16) Then
                        ' Do nothing, crosshairs already at position (avoids flashing the crosshairs)
                    Else
                        If dXValue >= .MinXValue(iXScale) And dXValue <= .MaxXValue(iXScale) And _
                           dYValue >= .MinYValue(iXScale) And dYValue <= .MaxYValue(iYScale) Then
                            .SetCrosshairsPosition(dXValue, dYValue, iXScale, iYScale)
                        End If
                    End If
                End With
            End If

        Catch ex As Exception
            GoTo ErrHandler

        End Try

        Exit Sub

ErrHandler:

    End Sub

    Private Function GetNearestDataPoint(ByVal Index As Integer, _
                                         ByVal xPos As Double, _
                                         ByVal yPos As Double, _
                                         ByRef FoundProfile As Integer, _
                                         ByRef FoundRow As Long, _
                                         ByRef FoundXValue As Double, _
                                         ByRef FoundYValue As Double, _
                                         ByRef XYChart As XYChartNet.XYChartNETCtl) As Boolean

        ' Gets nearest data point, and sets profile, row sample in array, and the actual X & Y values
        ' Returns True if data point found, else returns False

        Dim YStack As Integer
        Dim XScale As Integer
        Dim YScale As Integer
        Dim XScaleFactor As Double
        Dim YScaleFactor As Double
        Dim Profile As Integer
        Dim Row As Long
        Dim arrProfile(,) As Double

        Dim ThisXValue As Double
        Dim ThisYValue As Double
        Dim ThisXPos As Double
        Dim ThisYPos As Double
        Dim ThisDistanceFromMousePos As Double

        Dim FoundDistanceFromMousePos As Double

        Try
            FoundDistanceFromMousePos = 10 ^ 300
            FoundProfile = -1

            ' Find SampleNum in Profile
            With XYChart
                For Profile = 0 To .NumProfiles - 1
                    ' Set YStack
                    If .YStacking Then
                        YStack = Index
                    Else
                        YStack = 0
                    End If

                    If .Profile(Profile).Visible Then
                        ' Scales
                        XScale = .Profile(Profile).XScale
                        YScale = .Profile(Profile).YScale

                        If YScaleInYStack(XYChart, YScale, YStack) Then
                            ' Profile Data
                            ReDim arrProfile(.Profile(Profile).NumSamples - 1, 1)
                            arrProfile = .ProfileData(Profile)

                            ' Scale Factors
                            XScaleFactor = .XAxis(XScale).Scale.ScaleFactor
                            YScaleFactor = .YAxis(YScale).Scale.ScaleFactor

                            ' Find nearest data point
                            For Row = 0 To .Profile(Profile).NumSamples - 1
                                ThisXValue = arrProfile(Row, 0) * XScaleFactor
                                ThisYValue = arrProfile(Row, 1) * YScaleFactor
                                GetPos(YScale, YStack, XScale, ThisXPos, ThisYPos, ThisXValue, ThisYValue, XYChart)

                                ThisDistanceFromMousePos = Math.Sqrt(((ThisYPos - yPos)) ^ 2 + ((ThisXPos - xPos)) ^ 2)
                                If ThisDistanceFromMousePos < FoundDistanceFromMousePos Then
                                    FoundProfile = Profile
                                    FoundRow = Row
                                    FoundXValue = ThisXValue
                                    FoundYValue = ThisYValue
                                    FoundDistanceFromMousePos = ThisDistanceFromMousePos
                                End If
                            Next Row
                        End If
                    End If
                Next Profile
            End With

            GetNearestDataPoint = (FoundProfile >= 0)

        Catch ex As Exception
            GoTo ErrHandler

        End Try

        Exit Function

ErrHandler:

    End Function

    Private Function YScaleInYStack(ByRef XYChart As XYChartNet.XYChartNETCtl, _
                                    ByVal YScale As Integer, _
                                    ByVal YStack As Integer) As Boolean

        Dim i As Integer
        Dim NumYScales As Integer

        Try

            YScaleInYStack = False

            NumYScales = 0

            With XYChart
                If Not .YStacking Then
                    YScaleInYStack = True
                Else
                    For i = 0 To YStack
                        If i = YStack And YScale >= NumYScales And YScale < NumYScales + .YStack(i).NumYScales Then
                            YScaleInYStack = True
                            Exit For
                        Else
                            NumYScales += .YStack(i).NumYScales
                        End If
                    Next i
                End If
            End With

        Catch ex As Exception

        End Try

        Exit Function

ErrHandler:

    End Function

    Public Sub GetPos(ByVal YScale As Integer, _
                      ByVal YStack As Integer, _
                      ByVal XScale As Integer, _
                      ByRef xPos As Double, _
                      ByRef yPos As Double, _
                      ByVal dXValue As Double, _
                      ByVal dYValue As Double, _
                      ByRef XYChart As XYChartNet.XYChartNETCtl)

        ' Returns xPos and yPos in pixels given dXValue and dYValue

        Try
            With XYChart
                ' Determine X & Y values
                If .XAxis(XScale).Scale.ScaleType = XYChartNet.XYChartNETCtl.ScaleTypes.stLinear Then
                    ' Linear X Scale
                    xPos = (dXValue - .MinXValue(XScale)) / (.MaxXValue(XScale) - .MinXValue(XScale)) * .YStack(0).Width + .YStack(0).Left - 1
                Else
                    ' Log X Scale
                    xPos = (Math.Log(dXValue) / Math.Log(10) - Math.Log(.MinXValue(XScale)) / Math.Log(10)) / (Math.Log(.MaxXValue(XScale)) / Math.Log(10) - Math.Log(.MinXValue(XScale)) / Math.Log(10)) * .YStack(0).Width + .YStack(0).Left - 1
                End If

                If .YAxis(YScale).Scale.ScaleType = XYChartNet.XYChartNETCtl.ScaleTypes.stLinear Then
                    ' Linear Y Scale
                    yPos = .YStack(YStack).Top - (dYValue - .MaxYValue(YScale)) / (.MaxYValue(YScale) - .MinYValue(YScale)) * .YStack(YStack).Height
                Else
                    ' Log Y Scale
                    yPos = .YStack(YStack).Top - (Math.Log(dYValue) / Math.Log(10) - Math.Log(.MaxYValue(YScale)) / Math.Log(10)) / (Math.Log(.MaxYValue(YScale)) / Math.Log(10) - Math.Log(.MinYValue(YScale)) / Math.Log(10)) * .YStack(YStack).Height
                End If

            End With

        Catch ex As Exception
            GoTo ErrHandler

        End Try

ErrHandler:

    End Sub

    Public Sub GetXY(ByVal YScale As Integer, _
                     ByVal YStack As Integer, _
                     ByVal XScale As Integer, _
                     ByVal xPos As Double, _
                     ByVal yPos As Double, _
                     ByRef dXValue As Double, _
                     ByRef dYValue As Double, _
                     ByRef XYChart As XYChartNet.XYChartNETCtl)

        ' Returns dXValue and dYValue coordinates based on xPos and yPos

        Try
            With XYChart
                ' Determine X & Y values
                If .XAxis(XScale).Scale.ScaleType = XYChartNet.XYChartNETCtl.ScaleTypes.stLinear Then
                    ' Linear X Scale
                    dXValue = (xPos + 1 - .YStack(0).Left) / .YStack(0).Width * _
                                   (.MaxXValue(XScale) - .MinXValue(XScale)) + .MinXValue(XScale)
                Else
                    ' Log X Scale
                    dXValue = 10 ^ ((xPos + 1 - .YStack(1).Left) / .YStack(0).Width * _
                                   (Math.Log(.MaxXValue(XScale)) / Math.Log(10) - Math.Log(.MinXValue(XScale)) / Math.Log(10)) + Math.Log(.MinXValue(XScale)) / Math.Log(10))
                End If

                If .YAxis(YScale).Scale.ScaleType = XYChartNet.XYChartNETCtl.ScaleTypes.stLinear Then
                    ' Linear Y Scale
                    dYValue = .MaxYValue(YScale) - (yPos - .YStack(YStack).Top) / .YStack(YStack).Height * _
                                   (.MaxYValue(YScale) - .MinYValue(YScale))
                Else
                    ' Log Y Scale
                    dYValue = 10 ^ (Math.Log(.MaxYValue(YScale)) / Math.Log(10) - (yPos - .YStack(YStack).Top) / .YStack(YStack).Height * _
                                   (Math.Log(.MaxYValue(YScale)) / Math.Log(10) - Math.Log(.MinYValue(YScale)) / Math.Log(10)))
                End If

            End With

        Catch ex As Exception
            GoTo ErrHandler

        End Try

        Exit Sub

ErrHandler:

    End Sub

    Public Sub DrawShapeOnCanvas(ByRef gCanvas As System.Drawing.Graphics, _
                                 ByVal XYChart As XYChartNet.XYChartNETCtl, _
                                 ByVal YScale As Integer, _
                                 ByVal XScale As Integer, _
                                 ByVal MinXValue As Double, ByVal MaxXValue As Double, _
                                 ByVal MinYValue As Double, ByVal MaxYValue As Double, _
                                 ByVal Shape As eShape, _
                                 ByVal bIncludeHatch As Boolean, _
                                 ByVal BackColor As Color, _
                                 ByVal DrawBorder As Boolean, _
                                 ByVal BorderColor As Color, _
                                 ByVal BorderWidth As Single, _
                                 ByVal HatchStyle As HatchStyle, _
                                 ByVal HatchColor As Color)

        Try
            ' Get YStack
            Dim YStack As Integer
            With XYChart
                For YStack = 0 To .NumYStacks
                    If YScaleInYStack(XYChart, YScale, YStack) Then
                        Exit For
                    End If
                Next YStack
            End With

            ' Set Clip rectangle
            Dim x1limit As Double, y1limit As Double, x2limit As Double, y2limit As Double
            With XYChart
                GetPos(YScale, YStack, XScale, x1limit, y1limit, .MinXValue(XScale), .MinYValue(YScale), XYChart) ' Bottom left corner
                GetPos(YScale, YStack, XScale, x2limit, y2limit, .MaxXValue(XScale), .MaxYValue(YScale), XYChart) ' Top right corner
            End With
            gCanvas.SetClip(New Rectangle(x1limit, y2limit, x2limit - x1limit, y1limit - y2limit))

            ' Get 4 corners of shape
            Dim x1 As Double, y1 As Double, x2 As Double, y2 As Double
            GetPos(YScale, YStack, XScale, x1, y1, MinXValue, MinYValue, XYChart) ' Bottom left corner
            GetPos(YScale, YStack, XScale, x2, y2, MaxXValue, MaxYValue, XYChart) ' Top right corner
            Dim myRectangle As New Rectangle(x1, y2, x2 - x1, y1 - y2)

            Dim myBrush As SolidBrush
            myBrush = New SolidBrush(BackColor)

            Select Case Shape
                Case eShape.Elipse
                    If bIncludeHatch Then
                        gCanvas.FillEllipse(New HatchBrush(HatchStyle, HatchColor, BackColor), myRectangle)
                    Else
                        gCanvas.FillEllipse(myBrush, myRectangle)
                    End If
                    If DrawBorder Then
                        gCanvas.DrawEllipse(New Pen(BorderColor, BorderWidth), myRectangle)
                    End If

                Case eShape.Rectangle
                    ' Rectangle
                    If bIncludeHatch Then
                        gCanvas.FillRectangle(New HatchBrush(HatchStyle, HatchColor, BackColor), myRectangle)
                    Else
                        gCanvas.FillRectangle(myBrush, myRectangle)
                    End If
                    If DrawBorder Then
                        gCanvas.DrawRectangle(New Pen(BorderColor, BorderWidth), myRectangle)
                    End If

            End Select

            gCanvas.ResetClip()

        Catch ex As Exception
            GoTo ErrHandler

        End Try

        Exit Sub

ErrHandler:
        gCanvas.ResetClip()

    End Sub

    Public Sub DrawImageOnCanvas(ByRef gCanvas As System.Drawing.Graphics, _
                                 ByRef Image As Image, _
                                 ByVal XYChart As XYChartNet.XYChartNETCtl, _
                                 ByVal YScale As Integer, _
                                 ByVal XScale As Integer, _
                                 ByVal MinXValue As Double, ByVal MaxXValue As Double, _
                                 ByVal MinYValue As Double, ByVal MaxYValue As Double)

        Try
            ' Get YStack
            Dim YStack As Integer
            With XYChart
                For YStack = 0 To .NumYStacks
                    If YScaleInYStack(XYChart, YScale, YStack) Then
                        Exit For
                    End If
                Next YStack
            End With

            ' Set Clip rectangle
            Dim x1limit As Double, y1limit As Double, x2limit As Double, y2limit As Double
            With XYChart
                GetPos(YScale, YStack, XScale, x1limit, y1limit, .MinXValue(XScale), .MinYValue(YScale), XYChart) ' Bottom left corner
                GetPos(YScale, YStack, XScale, x2limit, y2limit, .MaxXValue(XScale), .MaxYValue(YScale), XYChart) ' Top right corner
            End With
            gCanvas.SetClip(New Rectangle(x1limit, y2limit, x2limit - x1limit, y1limit - y2limit))

            ' Get 4 corners of shape
            Dim x1 As Double, y1 As Double, x2 As Double, y2 As Double
            GetPos(YScale, YStack, XScale, x1, y1, MinXValue, MinYValue, XYChart) ' Bottom left corner
            GetPos(YScale, YStack, XScale, x2, y2, MaxXValue, MaxYValue, XYChart) ' Top right corner
            Dim myRectangle As New Rectangle(x1, y2, x2 - x1, y1 - y2)

            gCanvas.DrawImage(Image, myRectangle)

            gCanvas.ResetClip()

        Catch ex As Exception
            GoTo ErrHandler

        End Try

        Exit Sub

ErrHandler:
        gCanvas.ResetClip()

    End Sub

End Module
