Public Class Form1

    Private ChartData(,) As Double
    Const X_SCALE_MARGIN As Double = 0.5

    Private Sub Form1_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
        Const NUM_SAMPLES As Integer = 30 ' 30 days, since each sample is one day

        Dim myFont As New Font("Arial", 16, FontStyle.Italic Or FontStyle.Bold)
        Dim XScaleLabelFont As New Font("Arial", 32)

        ' Configure XY Chart NET control
        With XyChartNETCtl1
            .SendToBack()
            .Dock = DockStyle.Fill

            .NumProfiles = 1
            .NumXScales = 1
            .NumYScales = 1

            .Title.Label = "X Scale Date Vertical Labels"
            .Title.Font = myFont
            .Title.Color = Color.White

            ' Toolbar
            With .Toolbar
                .Visible = True
                .BackColor = Me.BackColor ' Color.Lavender
            End With

            ' Format Legend
            With .Legend
                .Visible = True
                .BorderVisible = False
                .YScaleVisible = False
            End With

            ' Show/Hide Scrollbars
            .Scrollbars.HorizontalVisible = True
            .Scrollbars.VerticalVisible = True

            ' Chart & plot formatting
            .BackColor = Color.SteelBlue
            With .Gradient
                .GradientOption = XYChartNet.XYChartNETCtl.GradientOptions.goCustom
                .Orientation = XYChartNet.XYChartNETCtl.OrientationOptions.ooVertical
                .StartColor = Color.SteelBlue
                .EndColor = Color.Blue
            End With

            .Plot.BackColor = Color.Lavender
            .Plot.Border.LineOption = XYChartNet.XYChartNETCtl.LineOptions.loNone

            ' X Axis
            With .XAxis(0)
                With .Grid
                    .LineOption = XYChartNet.XYChartNETCtl.LineOptions.loNone
                End With
                With .Scale
                    .Visible = True
                    .TicksColor = Color.White
                    .TicksFont = XScaleLabelFont ' Large font to make room for our labels
                    .NumericFormat = " " ' Force blank numbers
                    .Label = "X Scale Label"
                    .LabelColor = Color.White
                    .ScaleWidthHeight = 105 ' Make room for vertical text
                    .ScaleMode = XYChartNet.XYChartNETCtl.ScaleModes.smManual
                    .ScaleManualMin = DateTime.Now.Date.AddDays(-NUM_SAMPLES).ToOADate - X_SCALE_MARGIN
                    .ScaleManualMax = DateTime.Now.Date.ToOADate - X_SCALE_MARGIN
                    .ScaleInterval = 1 ' Force 1 day interval
                End With
            End With

            ' Y Axis
            With .YAxis(0)
                With .Grid
                    .LineOption = XYChartNet.XYChartNETCtl.LineOptions.loCustom
                    .LineColor = Color.Green
                End With
                With .Scale
                    .Visible = True
                    .ForceZeroDisplay = True
                    .Label = ""
                    .LabelColor = Color.White
                    .TicksColor = Color.White
                    .ScaleMode = XYChartNet.XYChartNETCtl.ScaleModes.smAuto
                End With
            End With

            ' Format Profile 0
            With .Profile(0)
                .XScale = 0
                .YScale = 0
                .Label = "Profile 0"

                .ChartFeatureType = XYChartNet.XYChartNETCtl.ChartFeatureOptions.cfBar
                .BarHorizontal = False
                .BarWidth = 0.5
                .BarBorderWidth = XYChartNet.XYChartNETCtl.WidthOptions.woOnePoint
                .BarFillGradientOption = XYChartNet.XYChartNETCtl.GradientOptions.goCustom
                .BarFillGradientOrientation = XYChartNet.XYChartNETCtl.OrientationOptions.ooVertical
                .BarFillGradientStartColor = Color.LightSteelBlue
                .BarFillGradientEndColor = Color.DarkBlue
                .BarBorderColor = Color.DarkBlue
                .BarReference = 0

                .LineOption = XYChartNet.XYChartNETCtl.LineOptions.loNone
                .MarkerOption = XYChartNet.XYChartNETCtl.LineOptions.loNone
                .NumSamples = NUM_SAMPLES
            End With

            ' Create random chart data, then feed into XYChartNET
            ReDim ChartData(.Profile(0).NumSamples - 1, 2 * .NumProfiles - 1)
            For i As Integer = 0 To .Profile(0).NumSamples - 1
                ChartData(i, 0) = DateTime.Now.Date.AddDays(-.Profile(0).NumSamples + i).ToOADate
                ChartData(i, 1) = 30 + 70 * Rnd()
            Next i
            .ChartData = ChartData

            ' Format Crosshairs
            With .Crosshairs
                .YCoordInLegend = True
                .Width = XYChartNet.XYChartNETCtl.WidthOptions.woFourPoint
                .Color = Color.Orange
                .CoordsBackcolor = Color.Blue ' Same colour as the chart back colour, so in effect hides the coordinates
                .HorizontalVisible = False
                .VerticalVisible = True
            End With

            .Refresh()

        End With

    End Sub

    Private Sub XyChartNETCtl1_Paint(ByVal sender As Object, ByVal e As System.Windows.Forms.PaintEventArgs) Handles XyChartNETCtl1.Paint
        Dim myFont As New Font("Arial", 8, FontStyle.Bold)

        Dim XPos As Single
        Dim YPos As Single

        Label1.Font = myFont

        With XyChartNETCtl1
            ' Display XScale Labels
            For xVal As Double = .AbsMinXValue(0) + X_SCALE_MARGIN To .AbsMaxXValue(0) Step 1
                If xVal >= .MinXValue(0) And xVal <= .MaxXValue(0) Then
                    Dim strLabel As String = Format(Date.FromOADate(xVal), "MMM dd, yyyy")
                    Label1.Text = strLabel ' Use to get width and height of text string

                    ' Determine position
                    XPos = .YStack(0).Left + .YStack(0).Width * (xVal - .MinXValue(0)) / (.MaxXValue(0) - .MinXValue(0)) - Label1.Height / 2
                    YPos = .YStack(0).Top + .YStack(0).Height + Label1.Width + 12

                    ' Display Label
                    e.Graphics.TranslateTransform(XPos, YPos)
                    e.Graphics.RotateTransform(-90)
                    e.Graphics.DrawString(strLabel, myFont, Brushes.White, 0, 0)
                    e.Graphics.ResetTransform()
                End If
            Next xVal

        End With
    End Sub

    Private Sub XyChartNETCtl1_PlotDoubleClick(ByVal Index As Integer, ByVal xPos As Integer, ByVal yPos As Integer) Handles XyChartNETCtl1.PlotDoubleClick
        XyChartNETCtl1.SetZoomOutAll()
    End Sub
End Class
