Public Class Form1

    Private ChartData(,) As Double

    Private Sub Form1_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load

        Dim myFont As New Font("Arial", 16, FontStyle.Italic Or FontStyle.Bold)
        Dim XScaleLabelFont As New Font("Arial", 32)

        Const NullDataValue As Double = 1.79 * 10 ^ 308

        ' Configure XY Chart NET control
        With XyChartNETCtl1
            .SendToBack()
            .Dock = DockStyle.Fill

            .NumProfiles = 1
            .NumXScales = 1
            .NumYScales = 1

            .Title.Label = "X Scale Vertical Labels"
            .Title.Font = myFont
            .Title.Color = Color.White

            ' Toolbar
            With .Toolbar
                .Visible = True
                .BackColor = Me.BackColor ' Color.Lavender
            End With

            ' Format Legend
            With .Legend
                .Visible = True
                .BorderVisible = False
                .YScaleVisible = False
            End With

            ' Hide Scrollbars
            .Scrollbars.HorizontalVisible = False
            .Scrollbars.VerticalVisible = False

            ' Chart & plot formatting
            .BackColor = Color.SteelBlue
            With .Gradient
                .GradientOption = XYChartNet.XYChartNETCtl.GradientOptions.goCustom
                .Orientation = XYChartNet.XYChartNETCtl.OrientationOptions.ooVertical
                .StartColor = Color.SteelBlue
                .EndColor = Color.Blue
            End With

            .Plot.BackColor = Color.Lavender
            .Plot.Border.LineOption = XYChartNet.XYChartNETCtl.LineOptions.loNone

            ' X Axis
            With .XAxis(0)
                With .Grid
                    .LineOption = XYChartNet.XYChartNETCtl.LineOptions.loCustom
                    .LineColor = Color.Green
                End With
                With .Scale
                    .Visible = True
                    .TicksColor = Color.White
                    .TicksFont = XScaleLabelFont ' Large font to make room for our labels
                    .NumericFormat = " "
                    .Label = "X Scale Label"
                    .LabelColor = Color.White
                    .ScaleMode = XYChartNet.XYChartNETCtl.ScaleModes.smAuto
                    .ScaleInterval = 1
                End With
            End With

            ' Y Axis
            With .YAxis(0)
                With .Grid
                    .LineOption = XYChartNet.XYChartNETCtl.LineOptions.loCustom
                    .LineColor = Color.Green
                End With
                With .Scale
                    .Visible = True
                    .Label = ""
                    .LabelColor = Color.White
                    .TicksColor = Color.White
                    .ScaleMode = XYChartNet.XYChartNETCtl.ScaleModes.smAuto
                End With
            End With

            ' Format Profile 0
            With .Profile(0)
                .XScale = 0
                .YScale = 0
                .Label = "Profile 0"
                .LineOption = XYChartNet.XYChartNETCtl.LineOptions.loCustom
                .LineWidth = XYChartNet.XYChartNETCtl.WidthOptions.woOnePoint
                .LineStyle = XYChartNet.XYChartNETCtl.StyleOptions.soSolid
                .LineColor = Color.Maroon
                .MarkerOption = XYChartNet.XYChartNETCtl.LineOptions.loCustom
                .MarkerStyle = XYChartNet.XYChartNETCtl.MarkerStyleOptions.msDiamond
                .MarkerSize = 4
                .MarkerFillColor = Color.Maroon
                .MarkerBorderColor = Color.Maroon
                .NumSamples = 10
            End With

            ' Create random chart data, then feed into XYChartNET
            ReDim ChartData(.Profile(0).NumSamples - 1, 2 * .NumProfiles - 1)
            For i As Integer = 0 To .Profile(0).NumSamples - 1
                ChartData(i, 0) = i * 1
                If i = 0 Then
                    ChartData(i, 1) = 0 ' Force first y value to zero
                Else
                    If Rnd() <= 0.2 Then ' Set random null values 20% of time
                        ChartData(i, 1) = NullDataValue
                    Else
                        ChartData(i, 1) = 100 * Rnd()
                    End If
                End If
            Next i
            .ChartData = ChartData

            ' Format Crosshairs
            With .Crosshairs
                .YCoordInLegend = True
                .Color = Color.Blue
                .Width = XYChartNet.XYChartNETCtl.WidthOptions.woTwoPoint
                .CoordsBackcolor = Color.Green
                .HorizontalVisible = False
                .VerticalVisible = True
            End With

            .Refresh()

        End With

    End Sub

    Private Sub XyChartNETCtl1_Paint(ByVal sender As Object, ByVal e As System.Windows.Forms.PaintEventArgs) Handles XyChartNETCtl1.Paint
        Dim myFont As New Font("Arial", 8, FontStyle.Bold)
        Dim strLabel As String

        Dim i As Integer
        Dim XPos As Single
        Dim YPos As Single

        Label1.Font = myFont

        With XyChartNETCtl1
            ' Display XScale Labels
            For i = .AbsMinXValue(0) To .AbsMaxXValue(0)
                If i >= .MinXValue(0) And i <= .MaxXValue(0) Then
                    strLabel = GetStringGivenNumber(i)
                    Label1.Text = strLabel ' Use to get width and height of text string

                    ' Determine position
                    XPos = .YStack(0).Left + .YStack(0).Width * (i - .MinXValue(0)) / (.MaxXValue(0) - .MinXValue(0)) - Label1.Height / 2
                    YPos = .YStack(0).Top + .YStack(0).Height + Label1.Width + 12

                    ' Display Label
                    e.Graphics.TranslateTransform(XPos, YPos)
                    e.Graphics.RotateTransform(-90)
                    e.Graphics.DrawString(strLabel, myFont, Brushes.White, 0, 0)
                    e.Graphics.ResetTransform()
                End If
            Next i

        End With
    End Sub

    Private Function GetStringGivenNumber(ByVal Number As Integer) As String
        Select Case Number
            Case 0
                GetStringGivenNumber = "Zero"
            Case 1
                GetStringGivenNumber = "One"
            Case 2
                GetStringGivenNumber = "Two"
            Case 3
                GetStringGivenNumber = "Three"
            Case 4
                GetStringGivenNumber = "Four"
            Case 5
                GetStringGivenNumber = "Five"
            Case 6
                GetStringGivenNumber = "Six"
            Case 7
                GetStringGivenNumber = "Seven"
            Case 8
                GetStringGivenNumber = "Eight"
            Case 9
                GetStringGivenNumber = "Nine"
            Case Else
                GetStringGivenNumber = ""
        End Select
    End Function

    Private Sub XyChartNETCtl1_PlotDoubleClick(ByVal Index As Integer, ByVal xPos As Integer, ByVal yPos As Integer) Handles XyChartNETCtl1.PlotDoubleClick
        XyChartNETCtl1.SetZoomOutAll()
    End Sub
End Class
